#
# spec file for package konversation
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           konversation
Version:        24.02.2
Release:        1.1.2.1
Summary:        A graphical IRC client by KDE
License:        GPL-2.0-or-later
URL:            https://konversation.kde.org/
Source0:        %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
# To get the path to qdbus
BuildRequires:  qt6-tools-qdbus
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_version}
BuildRequires:  cmake(KF6Codecs) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IdleTime) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6NotifyConfig) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(Qca-qt6) >= 2.2.0
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Tools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
# Only used by some very old scripts, no need to recommend it
Suggests:       qt6-tools-qdbus

%description
Konversation is an Internet Relay Chat (IRC) client built on the
KDE Platform.

Features:
* SSL server support
* Bookmarking support
* Multiple servers and channels in one single window
* DCC file transfer
* Multiple identities for different servers
* Text decorations and colors
* OnScreen Display for notifications
* Automatic UTF-8 detection
* Per channel encoding support
* Theme support for nick icons

%lang_package

%prep
%autosetup -p1

# search&replace not covered by %%patch0
sed -i 's#qdbus#qdbus6#' {doc,po/*/docs/konversation}/index.docbook

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html

%files
%license LICENSES/*
%doc AUTHORS ChangeLog NEWS README
%doc %{_kf6_htmldir}/en/konversation/
%{_kf6_applicationsdir}/org.kde.konversation.desktop
%{_kf6_appstreamdir}/org.kde.konversation.appdata.xml
%{_kf6_bindir}/konversation
%{_kf6_debugdir}/konversation.categories
%{_kf6_iconsdir}/hicolor/*/actions/konv_message.*
%{_kf6_iconsdir}/hicolor/*/apps/konversation.*
%{_kf6_knsrcfilesdir}/konversation_nicklist_theme.knsrc
%{_kf6_notificationsdir}/konversation.notifyrc
%{_kf6_sharedir}/dbus-1/services/org.kde.konversation.service
%{_kf6_sharedir}/konversation/

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/konversation

%changelog
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Delay tray setup until mainwindow state restored (kde#482316)
- Drop patch, merged upstream:
  * Delay-tray-setup-until-mainwindow-state-restored.patch
* Mon Mar 18 2024 Jiri Slaby <jslaby@suse.cz>
- add Delay-tray-setup-until-mainwindow-state-restored.patch (kde#482316)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Provide scripts with an env var to find qdbus (kde#349675)
  * Update NEWS
  * Update changelog
  * scripts/sysinfo: Add support for Plasma 6
  * Add error handling and modernize kpart loading
  * Fix the embedded Konsole (kde#480452)
- Drop patch, no longer needed:
  * 0001-Use-qdbus6-on-openSUSE.patch
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
- Replace 0001-Use-qdbus-qt5-on-openSUSE.patch with 0001-Use-qdbus6-on-openSUSE.patch
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: set version, appstream picking up non release service version.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * caps: prevent connection hang when none are requested (kde#471940)
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Disable Qt6 CI builds
  * Highlights sounds file picker: fix setting file filter by MIME types (kde#433667)
  * doc: use a non-deprecated entity for Frameworks
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Highlights sounds file picker: fix setting file filter by MIME types (kde#433667)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Build without KGlobalAccel on Windows
  * Show number of unseen nick mentions & query messages on launcher
    entry (kde#398047)
  * sound: Port away from Phonon
  * Don't use a QWaitCondition to do a dummy sleep
  * KStatusNotifierItem new API need to be guarded with KNotifications version
  * Support code for monospace formatting
  * Use SingleMainWindow=true now
  * Store state data in separate config file (kde#441575)
  * Update .gitignore
  * Bump KF5 min version & define KDE_COMPILERSETTINGS_LEVEL
  * Declare as DBusActivatable and install D-Bus service file
  * Add GitLab CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * KStatusNotifierItem new API need to be guarded with KNotifications version
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Only update wayland activation token if one was provided
  * Fix clicking the close button in systray mode if not foreground window
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * If restored or started hidden in systray, report start done to WM directly
  * Hide window to systray using SNI, for consistent storing of any window info
  * Help GNOME shell to know there is only one window/instance of Konversation
  * Set StartupWMClass in desktop file
  * Fix broken restore by session management
  * Fix unused empty space on tabbar if separate tab close button is disabled (kde#382056)
  * Fix quitting app without confirm dialog after previous canceling of quit (kde#444440)
  * Support and use modern code for Strikethrough formatting
  * On activation by KDBusService set proper startupId/activation token (kde#430561)
  * Channel Settings UI: bump max value of "User limit" to 99999 (kde#446673)
  * Fix plural arg string->int for log msg "[...] channel limit to %%1 nicks."
  * Bugfix: Correct behaviour of "case sensitive" tab completion option (kde#442109)
  * Add CI to stable branch
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Honor XDG_DATA_HOME for logfiles
  * Make setupUi public
  * Remove teardown function since there will only be one main menu
  * Give QMenus explicit parents
  * Add .kde-ci.yml
  * Port away from deprecated KShortcutsDialog::configure() method
  * Fix uptime reporting with 0 minutes
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * InputFilter: check NickInfoPtr object isn't null before using it (kde#437595)
  * Replace Freenode with Libera (kde#437589)
  * appdata: reference Libera, fix the wording
  * It can build against QT_NO_SIGNALS_SLOTS_KEYWORDS with last qca-2.2
  * Modernize code (using clang-tidy)
  * Remove unused includes
  * Remove unused forward declaration
  * Add support for cmake preset
- Drop patches:
  * 0001-Bulk-search-replace-to-mention-Libera-in-localized-f.patch
  * 0002-appdata-reference-Libera-fix-the-wording.patch
  * 0003-Replace-Freenode-with-Libera.patch
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Minimal changes to use libera.chat
  * Honor KDE Kiosk setting lineedit_reveal_password
- Drop upstream patch:
  * 0001-Minimal-changes-to-use-libera.chat.patch
* Wed Jun 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Reference libera.chat:
  * 0001-Minimal-changes-to-use-libera.chat.patch
  * 0002-appdata-reference-Libera-fix-the-wording.patch
  * 0003-Replace-Freenode-with-Libera.patch
  * 0001-Bulk-search-replace-to-mention-Libera-in-localized-f.patch
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Use KPasswordLineEdit for all password edit fields
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Use qdbus-qt5 in konversation scripts
- Stop owning directories provided by the filesystem package (boo#1184786)
- Add patch to allow using the konversation scripts on openSUSE
  * 0001-Use-qdbus-qt5-on-openSUSE.patch (boo#1184826)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * Consider # a valid channel name (kde#404072)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Fix shell scripts to also find qdbus-qt5
  * Handle \ in nicks when opening new query in ircview (kde#431045)
  * Use SSL for the server created by default
  * Don't allow spaces in ident and nick inputs (kde#422146)
  * Fix missed handling of a irc:// url cmdl arg on app start (kde#391698)
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * Remove X-KDE-ServiceTypes=DBUS/InstantMessenger (left-over from KIMProxy)
  * Fix possible memory leak in UPnPRouter
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Make hisc-apps-konversation.svgz an actually qzip'ed file
  * Remove unused decoder.h
  * Fix memory leak in ChannelDialog as well
  * Fix possible memory leak in ServerDialog
  * Fixed selected treeview index if activated by a notification
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- konversation is now released using the KDE release service.
* Tue Oct 27 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.7.7:
  * Fixed outdated color of existing nick items in the list after
    system color change
  * Fixed accidental large potential nick sorting timeout
  * Fixed tweak input box size to stop the text jumping around when
    selected
  * Fixed unneeded and potentially encoding switching re-encoding
    of key
  * Fixed disconnect for wrong slot for
    Chat::/TransferRecv::sendReverseAck
  * Support SVG nick icon themes, switch default to SVG
  * Add dark variant of default nick icon theme
  * Translations improved
* Wed Sep 30 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.7.6:
  * Fixed loading of nick icon theme to deal with multiple copies
  * Fixed configuration dialogs to have consistent indentation of
    subordinate options as well as spacings between labels & fields
  * Fixed building against Qt 5.15.
  * Fixed building against Qt 5.13.
  * Translations improved
- Drop patches merged upstream:
  * add-missing-includes.patch
  * 0001-Fix-build-with-Qt-5.13.patch
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Wed Apr 29 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build against Qt 5.15:
  * add-missing-includes.patch
* Mon Aug 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Fix-build-with-Qt-5.13.patch
* Wed Jun 27 2018 wbauer@tmo.at
- Update to 1.7.5:
  * Fixed building against Qt 5.11.
- Drop fix-build-qt-5.11.patch, merged upstream
* Fri Apr 27 2018 fabian@ritter-vogt.de
- Add patch to fix build with Qt 5.11:
  * fix-build-qt-5.11.patch
* Wed Nov 15 2017 wbauer@tmo.at
- Update to 1.7.4:
  * Fixed a bug causing the size of a custom chat text view font
    set via the configuration dialog to be ignored. A font size
    modification done via the Enlarge/Decrease Font Size actions
    is now applied on top of the configured size (or the system
    default font size, respectively).
* Fri Nov 10 2017 wbauer@tmo.at
- Update to 1.7.3:
  * Added a copy action to the context menu of nicknames in the
    chat text view.
  * Re-enabled channel mode buttons.
  * Reduced emission of Unicode directional control characters in
    the chat text view. Unnecessary control characters could
    sometimes cause problems with copying text from Konversation
    and pasting it into terminal applications, confusing them.
  * Fixed handling of nick and channel prefix characters
    potentially using the same set of symbols.
  * Removed redundant escaping of angle brackets in GECOS
    ("realname") field.
  * The nickname combobox will no longer change the nickname to
    the current value whenvever it loses focus.
  * Fixed color scheme handling in the treelist version on the tab
    bar, fixing an issue where the background and text color of
    the selected item would sometimes be the same, rendering the
    item unreadable.
  * Fixed handling of IRC URLs for channels starting with more
    than one #, addressing a percent-encoding problem with
    bookmarks of them.
  * Fixed custom chat text view font family reverting to system
    default font family upon using the increase/decrease font size
    actions.
  * Fixed chat text view font size adjusted via the
    increase/decrease font size actions reverting to configuration
    default when OK'ing the config dialog.
  * Fixed incorrect checkbox states in the Channel Invite dialog.
  * Fixed a crash in IRC v3 extended-join parsing.
  * Fixed a crash in parsing IRC color formatting codes.
    (CVE-2017-15923 boo#1068097)
  * Fixed a minor memory leak in the Join Channel dialog code.
  * Removed unnecessary nickname list debug message sent as
    warning.
- Drop fix-prefix-addressed-message-handling.patch, merged upstream
* Fri Aug 25 2017 fabian@ritter-vogt.de
- Add patch to fix prefix handling for channel types (kde#383801):
  * fix-prefix-addressed-message-handling.patch
* Tue May 16 2017 jengelh@inai.de
- Trim description from redundant phrasing, and ensure neutrality.
* Thu May 11 2017 wbauer@tmo.at
- Specify minimum KF5 version for build requirements
- Remove no longer used/necessary sonnet-devel BuildRequires
- Change package summary: it's "by" KDE, not "for" KDE
* Wed May 10 2017 wbauer@tmo.at
- Update to 1.7.2:
  * no code changes
  * incomplete and badly maintained translations removed that were
    accidentally included with the v1.7.1 release
- Update to 1.7.1:
  * Fixed requesting the znc.in/server-time-iso capability from the server.
  * Fixed SASL EXTERNAL authentication without an account name set in the
    Identity settings.
  * Fixed clicking on nickname links containing the ` character.
  * Fixed the Highlight page in the Configure Konversation dialog
    not enabling/disabling the Apply button correctly.
  * Minor cleanups in application metadata setup code.
* Thu May  4 2017 wbauer@tmo.at
- No need to define _kf5_appstreamdir any more, it doesn't build on
  42.1 anyway as it requires newer KDE Frameworks
- Update Qt build requirements to 5.5.0 or higher
* Sun Apr 16 2017 wbauer@tmo.at
- Update to 1.7:
  * Two-finger scroll on the vertical channel list is now less sensitive.
  * Fixed execution of bundled scripts showing an error about locating
    translation files when running on a system without kde4-config installed.
  * Fixed a bug in executable command line parsing for passed URLs.
  * Fixed Konversation failing to start on Windows systems without D-Bus
    (it would previously exit if it failed to initialize its D-Bus service).
  * Ported from deprecated KDE Frameworks APIs to 5.24+ API
    (v1.7 requires Frameworks 5.25 or higher).
  * Improved support for CAP negotiation
  * Output for CAP LS and CAP LIST is now shown in the server status view
  * Added support for IRCv3 CAP MULTI-PREFIX
  * Added support for IRCv3 CAP AWAY-NOTIFY
  * Added support for IRCv3 CAP ACCOUNT-NOTIFY
  * Added support for IRCv3 CAP EXTENDED-JOIN
  * Added support for IRCv3 CAP USERHOST-IN-NAMES
  * Added support for extended WHO
  * Added support for server-time and message tags
  * Added support for znc.in/server-time-iso, making buffer playback from ZNC
    much nicer
  * Added support for the SASL EXTERNAL authentication mechanism,
    e.g. needed for using Tor with freenode.
  * Redesigned search bar in chat views
  * Added support for font zooming to chat views
  * Improved bi-di text handling in chat views
  * The --restart command line argument works again
  * Fixed command line argument parsing when Konversation is already running
  * Fixed tab completion not working when pressing tab after a full
    existing nickname as prefix
  * Fixed the topic editor not updating when the topic changes
  * Fixed nickname links including the pipe character
  * Fixed the Invite dialog not closing on OK
  * Fixed angle bracket display in OSD message bubbles
  * Fixes to core protocol handling, e.g. in prefix parsing
  * Fixed crash on close when the nick menu has been shown
  * Fixed crash on quit
  * Fixed crash when closing views
  * Fixed crash in DCC resume dialogs without a Retry button
  * Fixed incorrect icon for the global away action
  * Minor UI layout cleanups, e.g. in the Behavior -> Chat Window settings
    page and fixes to tooltips
  * Code cleanups, e.g. removal of unused settings and related code paths,
    porting away from deprecated API, and more
  * Overhauled and corrected handbook & refreshed handbook screenshots to
    Frameworks 5 version
  * Build fixes for Windows (MSVC compatibility and winsock linking)
  * The Windows and Mac builds now have app icons
  * Improved code portability by using different byte swapping routines
  * Updated AppStream metadata
  * Konversation now depends on Qt 5.5+ and KDE Frameworks 5.25+
- Drop fix-crash-on-quit.patch, fixed upstream
* Sun Mar  5 2017 fabian@ritter-vogt.de
- Add upstream patch to fix crash on exit:
  * fix-crash-on-quit.patch
* Wed Aug  3 2016 wbauer@tmo.at
- Update to 1.6.2 hotfix release:
  * Fixed a bug causing various operations on server list data to crash,
    e.g. pressing "Edit" on a server sub-item in the Server List dialog.
  * Translations for AppData metadata added in v1.6.1.
* Sun Jul 24 2016 wbauer@tmo.at
- Update to 1.6.1:
  * Added an option to allow a server to bypass the global proxy settings.
  * Fixed a crash when changing the Qt style engine.
  * Fixed a crash when running "/exec -showpath" with no script name.
  * Fixed notification events for DCC Chats not working.
  * Fixed crash when closing the DCC Status tab.
  * Fixed crashes with the ISO-2022-JP encoding.
  * Fixed the "Close All Open Queries" action not working properly.
  * Minor UI polish, e.g. the margin under the nicklist when the Quick Button
    grid is disabled or emtpy.
  * Fixed missing icons on the Next/Previous buttons in the search bar.
  * On screens to small to fit Konversation's configuration dialog, the
    dialog will now show scrollbars around its content instead of the dialog
    buttons being forced off-screen.
  * Konversation now sets its window icon in a way that causes a hi-res icon
    to be available in window switchers such as Plasma's Alt+Tab UI.
  * Removed the spell checking language submenu from the context menu of the
    input bar - KDE Frameworks 5 now contains this upstream, leading to two
    submenus.
  * Fixed installing the Oxygen nickname list theme.
  * Fixed changes to the tab bar font's font weight being applied to the chat
    text area.
  * Minor changes to tooltips to support the Wayland windowing system better.
  * Fixed the Windows build.
  * Added KCrash (DrKonqi) support.
  * Improved support for the KDE Kiosk framework, fixing checks for the
    "shell_command" privilege.
  * Added AppData metadata for app stores.
* Thu Apr 30 2015 asterios.dramis@gmail.com
- Update to 1.6:
  * Improved support for character set aliases via KCharsets.
  * Improved behavior when reconnecting and Konversation had to use
    an alternate nickname for the previous connection because the
    preferred nickname was already in use: Konversation will now
    try harder to go back to nicknames sorted earlier in the
    identity's nickname list, instead of advancing down the list
    without checking whether earlier nicknames have become
    available again.
  * Konversation will no longer give up trying to connect when only
    a single nickname is configured and not available at connection
    time. Instead, it will do as many reconnection attempts as
    allowed by user configuration.
  * Fixed incorrect size calculations for the channel topic text
    label causing cut-off text and unwanted collapsing of the topic
    area.
  * Fixed a bug causing auto-connect not to connect to networks in
    the order they are listed in the Server List dialog.
  * Fixed a bug causing the main window not to be raised when an
    Konversation is started an additional time and the window is
    currently minimized.
  * The default tabs position is now 'Left', i.e. the treelist
    version of the tab bar.
  * Tabs can now be reordered by drag and drop again.
  * Fixed various rendering issues in the treelist version of the
    tab bar and made it high-DPI scaling-capable.
  * Fixed a bug causing Channel List tabs not to be sorted below
    the status tab of the server they belong to in the treelist
    version of the tab bar, and corrupt its contents.
  * Fixed margins in the Edit Network dialog.
  * Improved wording and correctness of several interface messages.
  * Fixed a bug causing some interface messages and labels not to
    use their translated versions when running with a language
    other than US English.
  * Fixed a bug causing Konversation not to generate default
    command aliases for installed scripts at startup anymore.
  * The bundled 'cmd' script now defaults to trying to decode
    command output as Utf-8 even when run on Python 2.
  * Fixed the bundled 'bug' script not working.
  * Fixed naming of bundled icons.
  * Konversation now opts into Qt's high-DPI pixmap handling.
  * Adjusted build system to use co-installable version of qca-qt5.
  * Fixed build failures on Windows.
  * Konversation now depends on KDE Frameworks v5.2.0 and Qt
    v5.3.0.
  * The default nickname list theme has been updated to KDE's new
    Breeze visual identity.
  * Notification events now have non-generic titles to prevent
    Plasma Desktop 5 from merging events from different sources.
  * Fixed a bug causing the "Focus Input Bar" action to be
    enabled/disabled at incorrect times.
- Package ported to KF5. Updated build and runtime requirements to
  the KF5 ones.
- Removed support for old openSUSE versions.
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Update to 1.5.1
  * Konversation 1.5.1 is a maintenance release containing only bug
  fixes. The included changes address several minor behavioral
  defects and a low-risk DoS security defect in the Blowfish
  ECB support. The KDE Platform version dependency has increased
  to v4.9.0 to gain access to newer Qt socket transport
  security flags.
  * Fixed a bug causing wildcards in command alias replacement
  patterns not to be expanded.
  * Fixed a bug causing auto-joining of channels not starting
  in # or & to sometimes fail because the auto-join command
  was generated before we got the CHANTYPES pronouncement
  by the server.
  * Added a size sanity check for incoming Blowfish ECB blocks.
  The blind assumption of incoming blocks being the expected
  12 bytes could lead to a crash or up to 11 byte information
  leak due to an out-of-bounds read. CVE-2014-8483.
  * Enabling SSL/TLS support for connections will now advertise
  the protocols Qt considers secure by default, instead of
  being hardcoded to TLSv1.
  * Fixed the bundled 'sysinfo' script not coping with empty
  lines in /etc/os-release.
  * Made disk space info in the bundled 'sysinfo' script more
  robust by forcing the C locale for 'df'.
  * Added an audio player type hint for Cantata to the bundled
  'media' script.
  * Fixed some minor comparison logic errors turned up by
  static analysis.
  * Konversation now depends on KDE Platform v4.9.0 or higher.
- Bump libkde4-devel BuildRequires to 4.9.0
* Fri Mar 14 2014 hrvoje.senjan@gmail.com
- Konversation can operate without kdepim4-runtime, so make it a
  Recommends instead of requires
* Mon Jan 20 2014 hpj@urpla.net
- Update to 1.5
  * Expanded interface translations
* Wed Jan  8 2014 hrvoje.senjan@gmail.com
- Update to 1.5-rc2
  * The bundled 'sysinfo' script now tries harder to determine the
  current CPU clock frequencies (it now looks at
  sys/.../cpufreq/scaling_cur_freq in addition to /proc/cpuinfo).
  * Fixed a bug causing the flood fill tool in DCC Whiteboard tabs
  not to use the correct color after using the color picker tool
  to set it.
  * Launching the default browser when clicking on links now works
  properly again on Windows.
  * Fixed a bug causing certain combinations of sorting and
  filtering in Channel List tabs not to work correctly, leading
  to partially unsorted list entries.
  * Minor rewordings and cleanups in UI text and the handbook for
  clarity and correctness, e.g. the "Notify" notification event
  is now known as "Nick on-line".
  * More information sources are now taken into account to update
  Konversation's idea of whether a particular nick is identified
  with services or not (information from IRC numeric 330 was
  previously discarded).
  * Fixed a bug causing Konversation to attempt to PART a channel
  that's no longer actually joined when closing a channel tab
  after having been kicked from the channel.
  * Some included PNG image files were badly encoded, this has
  been addressed.
  * Fixed a bug causing the file URL for an authentication
  certificate in the Identities dialog to be forgotten across
  application restarts.
  * The warning about text in the topic editor exceeding the
  server-allowed limit now calculates the threshold more
  correctly, taking encoding and IRC formatting expandos
  into account.
  * Konversation now depends on KDE Platform v4.7.0 or higher
  and Qt v4.7.0 or higher.
- Drop png_fix macro, icon has been fixed upstream
- Bump libkde4-devel BuildRequires to >= 4.7.0
* Tue Dec  3 2013 pgajdos@suse.com
- use png_fix macro [bnc#852862]
* Sun Mar 24 2013 coolo@suse.com
- readd download URL
* Thu Mar 14 2013 hrvoje.senjan@gmail.com
- Update to 1.5-rc1
  * Performance optimizations and code cleanup for processing NAMES
  messages from the server.
  * The bundled 'media' script has been rewritten from scratch to
  implement the MPRIS2 standard for interfacing with media players -
  and only the MPRIS2 standard. This means losing support for a
  number of legacy players which do not support MPRIS2
  * The bundled 'sayclip' script has been rewritten from scratch,
  removing the now-redundant flood handling found in the old version
  * The bundled 'bug' script has been rewritten from scratch, featuring
  improved error handling and adding internationalization support.
  * The bundled 'sysinfo' script has been rewritten from scratch.
  * All types of tabs which sport a prominent input widget will now see
  focus moved to that widget and the first keypress redirected when
  focus is on the treelist version of the tab bar while starting to
  type.
  * Performance improvements have been applied to hotpaths in the
  protocol implementation.
  * A '/umode' convenience command to set modes on self has been added.
  * The 'Mode change' notification event now sports a proper text
  payload describing what has happened.
  * The system tray icon now shows an overlay icon when global away
  is enabled.
  * The behavior of the 'Show/Hide Konversation' action has been
  simplified and tuned to do the correct thing in more scenarios.
  * A basic framework to support the IRC Client Capabilities Extension
  ("CAP") has been added.
  * The user interface for the Auto Identify settings in the Identities
  dialog has been extended by a combo box that allows choosing the
  type of authentification to be performed.
  * SASL PLAIN authentification is now supported.
  * Standard NickServ authentification has been further improved.
  * The server password-based authentification supported by some
  networks is now configurable in the Identities dialog as well,
  making it more discoverable and allowing to keep Auto Identify
  settings generally with the Identity rather than requiring going
  through the Edit Server dialog.
  * Added an option to restrict logging to private conversations
  (queries, DCC chats).
  * Both the regular tab bar and its listview version now implement
  "spring-loading".
  * Added support for authenticating via a SSL Client Certificate in
  the form of a PEM file if Konversation is built against KDE
  Platform v4.8.3 or higher.
  * Konversation now depends on KDE Platform v4.6.0 or higher and
  Qt v4.7.0 or higher.
  * Raw log tabs now use color coding to visually differenciate inbound
  and outbound messages, using the server message and channel message
  colors from the color settings respectively.
  * Queries now start with an info message listing the channels you
  and the other side have in common, i.e. that both of you are
  presently in.
  * The DCC Status transfer list update interval now depends on the
  graphics effects level setting in KDE System Settings
  * Fixed a bug causing the input box height not to be adjusted
  appropriately to fit the contents when the "Input box expands with text"
  option is enabled and the window is resized horizontally, causing
  the text to rewrap.
  * Fixed a bug causing the context menu for an item in the DCC Status
  transfer list to appear in the wrong position.
  * The list of placeholders available in Quick Button patterns now
  mention the previously undocumented "%%k" placeholder for the current
  channel's key and is sorted alphabetically.
  * When a Quick Button pattern replaces the current input box contents
  (due to the presence of the "%%n" expando in the pattern) they are
  now added to the input box history first.
  * Quick Button patterns now support a new "%%i" placeholder that
  is replaced with the current contents of the input box.
  * The double-click action command for Watched Nicks list entries now
  supports command aliases.
  * Fixed a bug causing wildcard expansion to be performed on the
  input box contents when they start with a Command Alias
  * The Quick Buttons options now feature a new checkbox that
  toggles whether Quick Buttons that operate on nicknames will be
  shown alongside other nickname-related actions in context menus
  throughout Konversation.
  * The Topic tab in the Channel Options dialog has been redesigned and
  rewritten from scratch, featuring a much improved UI and many bug fixes
  * The size of the Channel Options dialog is now synchronized between
  the dialogs for different channels and remembered across application
  restarts.
  * The widths of the columns in the Ban List tab in the Channel Options
  dialog is now synchronized across all Channel Options dialogs.
  * Fixed a bug causing the topic at the top of channel tabs not to return
  to its encrypted form after the decryption key for a channel has
  been deleted.
  * Debug builds of Konversation now understand a "--nui" command line
  argument to disable the check for whether Konversation is already
  running, thus allowing multiple instances of Konversation to be started.
  * Part and Quit messages now show the hostmask of the subject, consistent
  with Join messages.
  * Fixed a bug causing the What's This help tooltip for nickname lists
  to show the regular user icon instead of the away icon as the away
  icon example.
  * The desktop notification for a completed incoming DCC file transfer
  now offers an action to open/run the received file.
  * The nickname list theme preview in the configuration dialog now
  uses the same background color as the actual nickname lists.
  * Various fixed to tab stops and margins in the configuration dialog pages.
  * Minor UI fixes for the Queue Tuner (opened by /queuetuner), correcting
  icon use and button labels.
  * Removed excess white space from several warning dialog messages.
  * Fixed a bug causing the Watched Nicks to spam the active tab with
  repeated WHOIS requests for someone on the Watched Nicks List after
  opening a query tab to them while they were offline.
  * Added an action to manually apply the user-configured auto-replace rules
  to the input box contents without sending the message, enabling user
  review before doing so.
  * Added the ability to set a different spell-checking language for every
  tab, from the context menu of the input box.
  * Fixed several bugs in preserving per-tab encoding settings across
  application restarts.
  * Link opening now properly respects KDE's file type associating
  settings instead of always opening a web browser.
  * Fix Konversation not saving the unchecked "... a channel invitation
  is received" warning dialog option in the Warning Dialogs list in the
  configuration dialog
  * Unchecking the "... a channel invitation is received" warning dialog
  option in the Warning Dialogs list in the configuration dialog now
  sets the behavior for future channel join invitations to always
  joining them.
  * The default behavior upon receiving a channel join invitation is
  now to ask the user, instead of silently accepting the invitation.
  * Server status tabs for networks listed in the Server List dialog
  now have a "Connect at Startup" checkbox in their context menu, similar
  to the "Join  on Connect" checkbox in the context menu of channel tabs.
  * Added a workaround for behavior in the Phonon multimedia library that
  could lead to crashes on application quit when using custom highlight
  notification sounds.
  * Fixed a bug causing an ambiguous shortcut warning dialog when using the
  default ESC keyboard shortcut to invoke the Focus Input Box action
  after the search has been opened and the Focus New Tabs option was
  disabled while a new tab was opened.
  * Fixed a bug causing multiple ignore list entries with the same pattern
  not to be preserved across application restarts.
  * Fixed a bug causing the tab label for open log viewer tabs to be
  set to "ChatWindowObject" when switching the tab bar position between
  top or bottom and left.
  * Markup cleanups in the handbook and visual improvements to handbook
  icons in the PDF export on http://doc.kde.org.
  * Code cleanups for warnings issued by clang.
  * Build system improvements for kdepimlibs includes handling.
  * Made the code turning channel names into clickable links more strict
  about what types of trailing punctuation it incorporates into the link.
  * Fixed bugs causing currently joined channels not to react correctly to
  changes in the enabled state of the Automatic User Information Lookup
  setting.
  * The reaction to a change of the Automatic User Information Lookup interval
  setting has been improved considerably
  * All forms of opening a query (the '/query' command, clicking a nickname
  in the chat text display, double-clicking in the nickname list or the
  nickname list context menu action) now consistently move focus to an
  existing matching query tab, matching the behavior of various forms of
  joining an already-joined channel.
  * Minor visual (the selection decoration for server items now spans the
  whole row) and behavioral (when collapsing a network while one of its a
  server is selected, the selection is now moved to the network item instead
  of becoming invisible)
  * Fixed a bug causing the option to automatically focus new query tabs
  not to work correctly.
  * Fixed a bug causing IRC formatting state not to be reset at the end
  of a topic when showing it in a channel's chat text display, potentially
  causing the rest of the line to be malformatted.
  * Fixed a compilation problem on 64bit Windows.
  * If built against KDE Platform v4.8.3 or higher, the date column
  in the Url Catcher will now immediately reflect changes to the date
  format made in KDE's System Settings application.
  * Fixed a bug causing an application crash in response to an (illegal)
  '/unban <#channel>' command.
  * Removing newlines in the Edit Paste dialog can now handle Windows-style
  carriage return line breaks and whitespace characters other than
  ASCII 0x20.
  * Showing line and paragraph indicators in the Edit Paste dialog's
  text entry field unfortunately had to be disabled for the time being
  due to a bug in the underlying Qt code.
  * Leaving the "Use custom version reply" option's text field empty now
  disables responding to CTCP VERSION requests entirely instead of sending
  empty responses.
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sun Dec  4 2011 tittiatcoke@gmail.com
- Update to 1.4
  * URL and email detection in text views has been rewritten from
    scratch, greatly improving the handling of various types of
    URLs and the contexts they might appear in.
  * Extensive improvements to IRC formatting code handling,
    including the return of background color support.
  * Extensive, sometimes full rewrites of user interface elements
    such as nearly all context menus, the URL Catcher and the
    Warning Dialogs system for a long list of user interface
    improvements and bug fixes.
  * Improved SSL connection behavior.
  * Translation support and various other improvements in several bundled scripts.
  * Expanded Python scripting support via the introduction of an API support package.
  * Support for more IRC numerics.
  * Various bugfixes to input line command handling and connection behavior.
- Remove patch from the previous commit and removed patch to build
  against KDE < 4.3
* Mon Nov 21 2011 ctrippe@opensuse.org
- Workaround a bug in Qt which causes konversation to crash
  (bnc#731397,kde#210106)
* Sat Feb 26 2011 coolo@novell.com
- use recommends for -lang package
* Tue Feb  1 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Buildrequires:, %%description and %%install sections.
  * Use Suggests: instead of Requires: for konversation-lang package.
  * Removed /sbin/ldconfig from %%post and %%postun sections (not needed).
* Mon Dec 13 2010 coolo@novell.com
- fix file list for factory
* Sat Jul 17 2010 dmueller@suse.de
- (experimental) try building against KDE older than 4.3
* Fri Jul  2 2010 tittiatcoke@gmail.com
-Update to 1.3.1 (Maintenance release)
  * In addition to the '/disconnect' command, the graphical 'Disconnect'
  action and the '/quit' command can now be used to cancel an
  in-progress automatic reconnect in the event of connection failure
  as well.
  * The '/disconnect' and '/reconnect' commands now take optional quit
  message parameters.
  * Fixed crashes when pressing the "Edit" buttons below the server or
  channel lists in the "New Network"/"Edit Network" dialogs after
  adding a new server or channel and there was no item selected
  before in the respective list.
  * Fixed bugs causing the "Edit" buttons below the server or channel
  lists in the "New Network"/"Edit Network" dialogs to edit the
  previously selected list items rather than the ones shown as
  selected after adding a new server or channel.
  * Fixed a bug that could cause outdated status information for
  nicks to be displayed in channel nickname lists after a reconnect.
  * Efficiency improvements for channel join.
  * Don't send PING in response to PONG if another PING is already
  scheduled to be sent in the future.
  * Fixed numerous cases in which Konversation would incorrectly
  apply the KDE system color scheme to input lines, nickname lists
  and the listview version of the tab bar. This general overhaul
  of the relevant code also brought about minor efficiency and
  memory usage improvements.
  * Fixed nickname lists not respecting the "Alternate Background"
  setting when set to use custom colors.
  * Fixed the listview version of the tab bar not greying out disconnected
  tabs when set to use custom colors.
  * Fixed a bug causing the processing of incoming CTCP CLIENTINFO and
  CTCP TIME requests not to take the ignore list into account.
  * The "Insert IRC Color" dialog will now add a leading zero to colors
  which have single-digit numbers in the '%%C...' string it inserts into
  the input line, to allow the text that follows to start with a digit
  rather than such a digit getting interpreted as part of the color number.
  * Fixed a bug causing the Watched Nicknames Online nickname list for a
  network to be stored under the wrong network or lost entirely on
  application quit.
  * Fixed a bug causing the order of the Quick Buttons below the nickname
  list in channel tabs to be flipped every time the config dialog was OK'd.
  * Improved consistency of the filter fields in the URL Catcher and
  Channel List tabs with other KDE applications.
  * Correct use of singular or plural unit suffixes for several numeric
  preferences in the configuration dialog.
  * It is no longer possible to set the auto-way time to the nonsensical
  value of zero minutes. Rather, a minimum of one minute is now enforced.
* Tue Jun  8 2010 tittiatcoke@gmail.com
- Update to 1.3 Final
  * Added support for DCC WHITEBOARD, bringing collaborative
    drawing to IRC.
  * When showing the dialog informing the user about the local target
    file for an incoming DCC file transfer already existing that
    dialog now includes the sizes of the local file and the file
    the sender is offering up.
  * The "Clear All Windows" action will now also resets the
    notification state of all tabs (i.e. removes active new message
    or highlight notifications from the tab bar).
  * several bugfixes
  * The text in notification messages used to be wrapped every 50
    characters, an old workaround for problems with KDE 3.x's bubble
    notifications. This has been removed now since it's no longer
    needed with modern notification frontends such as Plasma's,
    and produces rather ugly results there.
  * Made it possible again to initate DCC file transfers to a query
    partner by dragging files or URLs onto the chat text area of
    the query.
  * When building against the KDE Platform v4.4.3 libraries, the
    auto-away functionality will now make use of the new KIdleTime
    library to determine user activity and inactivity rather than
    use its own code.
  * SSL support now integrates with KDE's certificate handling
    again, as it used to in the KDE 3 version.
  * Not reacting to an SSL certificat validation error dialog in
    a timely manner should no longer result in Konversation locking
    up.
  * In-progress automatic reconnect in the event of connection
    failure can now be aborted by using the '/disconnect' command.
* Fri Feb 12 2010 wstephenson@suse.de
- update to version 1.2.3
  * Increased robustness of DBUS IPC.
* Fri Feb 12 2010 tittiatcoke@gmail.com
- update to version 1.2.2
  * Added support for passive DCC chat.
  * Made it possible to accept/reject DCC chats like DCC file transfers.
  * Added an option to auto-accept DCC chats (previously it would
    always auto-accept).
  * Added a confirmation dialog for closing DCC chats, consistent with
    other conversation tabs.
  * Improved the sanity-checking code for the validity of ports used
    in DCC operations.
  * Fixed connection attempts possibly stalling when there is a problem
    with executing the associated identity's pre-shell command
  * Fixed /setkey, /delkey and /showkey treating their target arguments
    (i.e. a channel or a query) case-sensitive.
  * Fixed the encryption key for a query getting lost if the other end
    changes their nickname.
  * Added support for KStatusNotifierItem, the new system tray API in KDE.
  * Fixed a bug causing multiple auto-replacements in a single message not to work.
  * Made it possible to include syntax normally used to refer to a subgroup
    of the matching pattern as normal text in the replacement pattern of a
    regular expression auto-replace, by escaping it like this: %%%%1.
  * Fixed a bug causing an empty MODE message to be sent to the server
    preceding the correct one when using /op, /deop and the like.
  * Fixed a bug causing as many mode chars as target nicknames given to
    commands like /op, /deop etc. to be sent as part of every single
    resultant MODE messages sent to the server.
  * Added support for amarok:// URLs in chat text views and channel topics.
  * Fixed a bug causing Konversation to treat "Page Up" and "Page Down"
    key events with any modifier (e.g. Ctrl) the same as without any modifier,
    making such combinations unavailable as shortcuts for other actions.
  * Fixed a bug causing the status bar to remain stuck displaying the
    description of a menu action if subsequently hovering other actions without
    a description set.
  * Further work on reducing the use of the qt3support/kde3support libraries
    throughout the codebase.
  * The design of the search bar has been made more consistent with the search
    bars found in other KDE applications (e.g. Konqueror, Konsole and KWrite).
  * Added a "--noautoconnect" command line argument to disable auto-connecting
    to any IRC networks on application startup.
  * The invite dialog now has a drop-down offering the options "Always ask",
    "Always join" and "Always ignore" for future default behavior, rather than
    just a "Don't ask again" checkbox that wasn't sufficient to cover all scenarios.
  * The "Hide Nicklist" action has been renamed "Show Nicklist" to comply with
    the KDE 4 HIG.
  * URLs are no longer decoded before being passed to the web browser, fixing
    the opening of some links from the chat text view.
  * Fixed a bug causing the application to crash when pressing the left or right
    arrow keys after selecting an active file transfer in the DCC Status tab's
    transfer list when using Qt 4.6.
  * Improved performance of the DCC Status tab's transfer list.
  * It's now possible to add nicknames to the Watched Nicknames Online list,
    as well as remove them, right from the tab rather than having to go to
    the config dialog.
  * Fixed a bug that would cause the "Choose Association" KDE address book
    integration action to create a new contact in the address book.
  * It's now possible to add a nickname to the watch list of all networks in
    the Watched Nicknames Online tab at once.
  * Fixed a bug causing the opening of all bookmarks in a bookmark folder at
    once not to work.
  * The ban list interface has seen a facelift.
  * The topic history list in the Channel Settings dialog has seen a number of
    behavioral and reliability improvements.
  * Updated various dialog layouts to better comply with the alignment rules
    of the KDE 4 HIG.
  * The URL list in the URL catcher tab now sports a new Date column and can be
    sorted. The sorting settings are saved and restored across sessions.
  * Fixed a bug causing the vertical spacing inbetween the regular mode checkboxen
    on the "Modes" tab of the Channel Settings dialog to change when the display
    of the advanced mode list was toggled or the dialog was resized.
  * The Join Channel dialog now sports a combo box listing all open connections
  * Fixed a bug causing the "Clear History" item in the context menu of the
    channel combobox in the "Join Channel" dialog not to clear the history correctly;
  * Fixed a bug causing a crash on Windows when middle-clicking the chat text view.
  * Fixed a bug causing the pasting of clipboard contents using keyboard shortcuts
    not to work when the chat text has keyboard focus.
  * Fixed a bug causing the setting or removing of a 'q' channel mode to be
    mistakenly announced as giving or taking channel owner privileges on networks
    where it's actually a type of ban.
  * Fixed a bug causing a crash when pressing the "Ok" button in the "Join Channel"
    dialog without entering anything in the dialog's "Channel:" input field beforehand.
  * More robust Unicode handling to make interaction with the D-Bus daemon more reliable.
* Thu Nov 12 2009 tittiatcoke@gmail.com
- Update to 1.2.1
  * Fixed a crash when cancelling the warning dialog that is shown
    upon receiving two incoming DCC file transfer requests using
    the same file name.
  * Fixed a crash when using the "Clear Completed" action in the DCC
    Status tab after having previously used the "Clear" action to
    remove specific transfers from the transfer list.
  * Fixed a crash when using the "Clear" or "Clear Completed" action
    in the DCC Status tab after creating a mixed selection of removable
    (e.g. completed, or failed) and non-removable (e.g. sending) transfers
    and the last addition to the selection was a removable transfer.
  * Added a "Bookmark Tabs as Folder" feature.
  * Added the ability to open the contents of an entire bookmark folder at
    once (aka "Open Folder in Tabs").
  * Made the default generated bookmark titles more verbose: The Format is
    now "Channel (Network-or-Server)".
  * Added support for reacting to changes in network availability as reported
    by KDE's Solid subsystem. If the network goes down, Konversation will now
    no longer make futile attempts to reconnect the affected connections.
    Instead, it will reconnect once the network comes back up.
  * Variable expansion (%%B, %%C, %%I, etc.) is no longer done in text segments
    recognized as URLs to avoid clashes with percent-encoded characters in URLs
    copied from web browsers, such as German umlauts.
  * Made tooltips for truncated labels in the listview version of the tab bar
    work again with newer versions of Qt.
  * Fixed a bug that caused the Watched Nicknames Online list to show the wrong
    or no tooltip when hovering a list item with the mouse pointer.
  * The default destination folder for incoming DCC file transfers is now the
    "Downloads paths" configured in System Settings or the equivalent in other
    desktop environments (under the hood, this is a shared XDG setting).
  * Making and then comitting unrelated changes in the Channel Settings dialog
    could cause unintentionally setting the channel's topic to an older version
    if someone else had changed the topic since the first time the dialog was
    opened or while the dialog was open, due to a bug in the code that avoids
    such external topic changes interfering with concurrent local editing of
    the topic. This has been fixed.
  * The contents of the topic edit field in the Channel Settings dialog will
    now reflect the selected item in the topic history list until the user
    starts editing.
  * Fixed a bug that could cause user mode changes occurring directly after
    joining a channel not to be reflected by the channel's nickname list.
  * Fixed a bug causing the "Open File" context menu action for DCC file
    transfer items in the transfer list in the DCC Status tab not to work for
    incoming file transfers.
  * Added support for RPL_HOSTHIDDEN.
* Wed Oct 28 2009 binner@kde.org
- fix version to make it an upgrade from previous package
* Fri Oct  9 2009 wstephenson@novell.com
- Update to 1.2
  * When dragging a link from the chat text view, the drag object will now
    contain a plain text version in addition to the URL version. This allows
    dragging a link to places that don't accept URL drops, such as Konsole,
    the Konqueror address bar or Konversation's own input line.
* Sat Oct  3 2009 wstephenson@novell.com
- Update to 1.2 RC 1
  * Fixed the scrollbar thumb not remaining at the bottom when the
    chat text view is resized
  * Fixed file transfer progress bar not updating
  * Fixed incoming DCC file transfer crash
  * Fixed keyboard focus bug when typing using dead keys
  * Fixed selection bug when showing remember line after a clicked
    link
  * Fixed a bug causing the automatic scroll-down not to work when
    more backlog is replayed than the viewport can show at once at
    channel join.
  * The "Advanced Modes" listing in the "Modes" tab of the Channel
    Settings dialog will now properly vertically expand as the
    dialog is resized even to a very large height.
  * Fixed crash while manipulating a channel's ban list.
  * Fixed a bug causing the moving of child tabs of a network tab
    in the treelist version of the tab bar not to work using the
    keyboard shortcuts, context menu actions or "Window" menu
    actions.
* Mon Sep 21 2009 tittiatcoke@gmail.com
- Update to 1.2 Beta 1
  * Added a topic widget for Konsole windows and hooked it
    up to the KPart's setWindowCaption signal
  * Added tooltips to items in the new DCC transfer lists that
    describe the transfer's status more verbosely.
  * Fixed the OSD stealing focus when it appears on Windows.
  * Added a "Manage Profiles" button to the information area above
    the terminal area in Konsole tabs.
  * Added SOCKS v5 and HTTP proxy support. Proxy credentials are
    stored in KWallet.
  * Moved the buttons in the DCC Status tab to a toolbar,
    similar to how things were already laid out in log viewer tabs.
  * Other bug fixes
* Sun Aug  9 2009 binner@kde.org
- update to 1.2 Alpha 6: hotfix release addressing a DCC crash
* Wed Aug  5 2009 beineri@opensuse.org
- update to 1.2 Alpha 5 release: significant performance and memory
  usage improvements in several areas of the application, such as
  channel nickname lists, backlog loading, Channel List tabs and the
  URL catcher - the latter two have also seen a fair number of inter-
  face refinements, making them much more enjoyable to use. The DCC
  subsystem has seen the addition of IPv6 support and a '/dcc get'
  command to accept an incoming file transfer from the input line.
  Various smaller additions and improvements have been made as well,
  including the usual share of bug fixes.
- don't require akonadi-runtime
* Sat Jul 25 2009 beineri@opensuse.org
- add trunk diff (revision 1002348)
* Sat Jul  4 2009 beineri@opensuse.org
- added patch to fix build
* Sat Jul  4 2009 tittiatcoke@gmail.com
- update to 1.2 Alpha 4 release
  New features in this release include UPnP NAT traversal support
  for DCC file transfers and chats, DH1080 key exchange support for
  Blowfish encryption and the ability to automatically split very
  long actions (i.e. usage of the '/me' command) into multiple messages
  conforming to the maximum length of an IRC message (this was already
  supported for regular messages for some time).
- Added dependency for libqca2
* Wed Jun  3 2009 beineri@opensuse.org
- update to 1.2 Alpha 3 release: fair amount of annoying bugs en-
  countered in day-to-day usage, as well as a serious bug in
  handling NAMES messages from IRC servers. Also some UI changes
  that we'd like to get your feedback on: We've changed the default
  tab completion mode to "Cycle Nicklist", and we've removed the
  frame around the tab widget when using the listview version of
  the tab bar.
* Wed May 27 2009 beineri@opensuse.org
- reviewed changes
* Tue May 26 2009 tittiatcoke@gmail.com
- update to 1.2 Alpha 2 release, see ChangeLog for a summary of
  bugfixes and new features which happened during KDE4 port cycle
* Wed May 20 2009 beineri@opensuse.org
- update to 1.2 Alpha 1 release, see ChangeLog for a summary of
  bugfixes and new features which happened during KDE4 port cycle
* Wed May 13 2009 beineri@opensuse.org
- update to r967285
* Sat May  2 2009 beineri@opensuse.org
- update to r962383
* Thu Apr 23 2009 beineri@opensuse.org
- update to r958022
* Thu Apr  9 2009 beineri@opensuse.org
- update to r951439
* Tue Mar 31 2009 dmueller@suse.de
- remove pre_checkin.sh magic
* Mon Mar 30 2009 dmueller@suse.de
- add missing akonadi dependency
* Sun Mar 22 2009 beineri@opensuse.org
- update to r942587
  * binary renamed back from konvi to konversation
* Mon Mar 16 2009 dmueller@suse.de
- update to r939650
  * merged/renamed kde4-konversation to konversation
* Thu Mar  5 2009 wstephenson@suse.de
- update to r935535
* Wed Feb 25 2009 stbinner@suse.de
- update to r931365
* Wed Feb 18 2009 dmueller@suse.de
- obsolete konversation on 11.2
* Tue Feb 17 2009 stbinner@suse.de
- update to r927519
* Sat Feb 14 2009 stbinner@suse.de
- update to r926039
* Sun Feb  8 2009 stbinner@suse.de
- update to r923134
* Sat Feb  7 2009 stbinner@suse.de
- update to r922461
* Fri Feb  6 2009 stbinner@suse.de
- update to r922014
* Thu Feb  5 2009 stbinner@suse.de
- update to r921671
* Wed Feb  4 2009 stbinner@suse.de
- update to r921325
* Tue Feb  3 2009 stbinner@suse.de
- initial package of r920614 svn snapshot
